@@ -15,11 +15,11 @@ class _View {
   }
 
   bool _Get(int opt_num) {
-    List<bool>* overlay = opt_stacks->index(opt_num);
+    List<bool>* overlay = opt_stacks->index_(opt_num);
     if ((overlay == nullptr) or len(overlay) == 0) {
-      return opt0_array->index(opt_num);
+      return opt0_array->index_(opt_num);
     } else {
-      return overlay->index(-1);
+      return overlay->index_(-1);
     }
   }
 
@@ -60,6 +60,7 @@ class Exec : public _View {
   bool pipefail() { return _Get(option_i::pipefail); }
   bool inherit_errexit() { return _Get(option_i::inherit_errexit); }
   bool nullglob() { return _Get(option_i::nullglob); }
+  bool verbose_errexit() { return _Get(option_i::verbose_errexit); }
   bool noexec() { return _Get(option_i::noexec); }
   bool xtrace() { return _Get(option_i::xtrace); }
   bool verbose() { return _Get(option_i::verbose); }
@@ -74,7 +75,6 @@ class Exec : public _View {
   bool extglob() { return _Get(option_i::extglob); }
   bool eval_unsafe_arith() { return _Get(option_i::eval_unsafe_arith); }
   bool compat_array() { return _Get(option_i::compat_array); }
-  bool verbose_errexit() { return _Get(option_i::verbose_errexit); }
   bool allow_command_sub() { return _Get(option_i::allow_command_sub); }
   bool dynamic_scope() { return _Get(option_i::dynamic_scope); }
   bool redefine_module() { return _Get(option_i::redefine_module); }
