@@ -105,6 +105,8 @@ const char* Id_str(int tag) {
     return "Id.Unknown_Tok";
   case Id::Unknown_Backslash:
     return "Id.Unknown_Backslash";
+  case Id::Unknown_DEqual:
+    return "Id.Unknown_DEqual";
   case Id::Eol_Tok:
     return "Id.Eol_Tok";
   case Id::Ignored_LineCont:
@@ -611,6 +613,8 @@ const char* Id_str(int tag) {
     return "Id.ControlFlow_Return";
   case Id::ControlFlow_Exit:
     return "Id.ControlFlow_Exit";
+  case Id::LookAhead_FuncParens:
+    return "Id.LookAhead_FuncParens";
   case Id::Glob_LBracket:
     return "Id.Glob_LBracket";
   case Id::Glob_RBracket:
@@ -829,6 +833,8 @@ const char* Kind_str(Kind tag) {
     return "Kind.KW";
   case Kind::ControlFlow:
     return "Kind.ControlFlow";
+  case Kind::LookAhead:
+    return "Kind.LookAhead";
   case Kind::Glob:
     return "Kind.Glob";
   case Kind::Format:
