@@ -310,23 +310,21 @@ class SetNamedAction : public _Action {
 args::_Attributes* Parse(flag_spec::_FlagSpec* spec, args::Reader* arg_r);
 args::_Attributes* ParseLikeEcho(flag_spec::_FlagSpec* spec, args::Reader* arg_r);
 args::_Attributes* ParseMore(flag_spec::_FlagSpecAndMore* spec, args::Reader* arg_r);
-extern Str* _FLAG_ERE;
-args::_Attributes* ParseOil(flag_spec::_OilFlagSpec* spec, args::Reader* arg_r);
-inline Str* fmt94(Str* a0) {
+inline Str* fmt98(Str* a0) {
   gBuf.reset();
   gBuf.write_const("got invalid argument to boolean flag: ", 38);
   gBuf.format_r(a0);
   return gBuf.getvalue();
 }
 
-inline Str* fmt95(Str* a0) {
+inline Str* fmt99(Str* a0) {
   gBuf.reset();
   gBuf.write_const("Invalid option ", 15);
   gBuf.format_r(a0);
   return gBuf.getvalue();
 }
 
-inline Str* fmt96(Str* a0) {
+inline Str* fmt100(Str* a0) {
   gBuf.reset();
   gBuf.write_const("Invalid action name ", 20);
   gBuf.format_r(a0);
