@@ -15,6 +15,7 @@ const int TERM_ECHO = ECHO;
 const int EOF_SENTINEL = 256;
 const int NEWLINE_CH = 10;
 
+Tuple2<int, int> WaitPid();
 Tuple2<int, int> Read(int fd, int n, List<Str*>* chunks);
 Tuple2<int, int> ReadByte(int fd);
 Str* ReadLine();
@@ -23,6 +24,13 @@ int Chdir(Str* dest_dir);
 Str* GetMyHomeDir();
 Str* GetHomeDir(Str* user_name);
 
+class ReadError {
+ public:
+  ReadError(int err_num_) : err_num(err_num_) {
+  }
+  int err_num;
+};
+
 inline Str* GetUserName(int uid) {
   assert(0);
 }
