@@ -1,5 +1,9 @@
 // posix.cc: Replacement for native/posixmodule.c
 
+// clang-format off
+#include "myerror.h"  // for OSError; must come first
+// clang-format on
+
 #include "posix.h"
 
 #include <fcntl.h>     // open
@@ -13,4 +17,10 @@ int open(Str* path, int flags, int perms) {
   return ::open(path0.Get(), flags, perms);
 }
 
+void dup2(int oldfd, int newfd) {
+  if (::dup2(oldfd, newfd) < 0) {
+    throw new OSError(errno);
+  }
+}
+
 }  // namespace posix
