@@ -3,7 +3,6 @@
 #ifndef POSIX_H
 #define POSIX_H
 
-#include <sys/wait.h>  // waitpid
 #include <unistd.h>
 
 #include "mylib.h"
@@ -71,7 +70,12 @@ inline void lstat() {
 }
 
 inline Tuple2<int, int> pipe() {
-  assert(0);
+  int fd[2];
+  if (::pipe(fd) < 0) {
+    // TODO: handle errno
+    assert(0);
+  }
+  return Tuple2<int, int>(fd[0], fd[1]);
 }
 
 inline int close(int fd) {
@@ -96,20 +100,12 @@ inline void _exit(int status) {
   exit(status);
 }
 
-inline void write(int fd, Str* value) {
-  assert(0);
-}
-
-inline Tuple2<int, int> waitpid(int pid, int options) {
-  int status;
-  int result_pid = ::waitpid(pid, &status, options);
-  return Tuple2<int, int>(result_pid, status);
+inline void write(int fd, Str* s) {
+  ::write(fd, s->data_, s->len_);
 }
 
 // Can we use fcntl instead?
-inline void dup2(int oldfd, int newfd) {
-  assert(0);
-}
+void dup2(int oldfd, int newfd);
 
 int open(Str* path, int flags, int perms);
 
@@ -133,7 +129,7 @@ inline void execve(Str* argv0, List<Str*>* argv, Dict<Str*, Str*>* environ) {
   // Annoying const_cast
   // https://stackoverflow.com/questions/190184/execv-and-const-ness
   for (int i = 0; i < n; ++i) {
-    _argv[i] = const_cast<char*>(argv->index(i)->data_);
+    _argv[i] = const_cast<char*>(argv->index_(i)->data_);
   }
   _argv[n] = nullptr;
 
