@@ -1,3 +1,7 @@
+// clang-format off
+#include "core_pyutil.h"  // for BackslashEscape; must come first because of 'errno' issue
+// clang-format on
+
 #include <errno.h>
 #include <fcntl.h>  // O_RDWR
 
@@ -5,8 +9,7 @@
 
 #include "core_error.h"
 #include "core_pyerror.h"
-#include "core_pyos.h"    // Chdir
-#include "core_pyutil.h"  // BackslashEscape
+#include "core_pyos.h"  // Chdir
 #include "frontend_flag_spec.h"
 #include "frontend_match.h"
 #include "id.h"
@@ -168,9 +171,9 @@ TEST libc_test() {
   List<Str*>* results =
       libc::regex_match(new Str("(a+).(a+)"), new Str("-abaacaaa"));
   ASSERT_EQ_FMT(3, len(results), "%d");
-  ASSERT(str_equals(new Str("abaa"), results->index(0)));  // whole match
-  ASSERT(str_equals(new Str("a"), results->index(1)));
-  ASSERT(str_equals(new Str("aa"), results->index(2)));
+  ASSERT(str_equals(new Str("abaa"), results->index_(0)));  // whole match
+  ASSERT(str_equals(new Str("a"), results->index_(1)));
+  ASSERT(str_equals(new Str("aa"), results->index_(2)));
 
   results = libc::regex_match(new Str("z+"), new Str("abaacaaa"));
   ASSERT_EQ(nullptr, results);
@@ -192,7 +195,7 @@ TEST libc_test() {
   // This depends on the file system
   auto files = libc::glob(new Str("*.md"));
   ASSERT_EQ_FMT(1, len(files), "%d");
-  print(files->index(0));  // should get README.md only
+  print(files->index_(0));  // should get README.md only
 
   auto files2 = libc::glob(new Str("*.pyzzz"));
   ASSERT_EQ_FMT(0, len(files2), "%d");
@@ -352,9 +355,26 @@ TEST bool_stat_test() {
 }
 
 TEST pyos_test() {
+  // This test isn't hermetic but it should work in most places, including in a
+  // container
+  int err_num = pyos::Chdir(new Str("/"));
+  ASSERT(err_num == 0);
+
+  err_num = pyos::Chdir(new Str("/nonexistent__"));
+  ASSERT(err_num != 0);
+
+  Dict<Str*, Str*>* env = pyos::Environ();
+  Str* p = env->get(new Str("PATH"));
+  ASSERT(p != nullptr);
+  log("PATH = %s", p->data_);
+
+  PASS();
+}
+
+TEST pyos_readbyte_test() {
   // Write 2 bytes to this file
-  char* tmp_name = "_tmp/pyos_unit_test";
-  int fd = ::open(tmp_name, O_CREAT|O_RDWR, 0644);
+  char* tmp_name = "_tmp/pyos_ReadByte";
+  int fd = ::open(tmp_name, O_CREAT | O_RDWR, 0644);
   if (fd < 0) {
     printf("1. ERROR %s", strerror(errno));
   }
@@ -362,8 +382,7 @@ TEST pyos_test() {
   write(fd, "SH", 2);
   close(fd);
 
-  // open needs an absolute path for some reason?  _tmp/pyos doesn't work
-  fd = ::open(tmp_name, O_CREAT|O_RDWR, 0644);
+  fd = ::open(tmp_name, O_CREAT | O_RDWR, 0644);
   if (fd < 0) {
     printf("2. ERROR %s", strerror(errno));
   }
@@ -382,20 +401,37 @@ TEST pyos_test() {
 
   close(fd);
 
-  // This test isn't hermetic but it should work in most places, including in a
-  // container
+  PASS();
+}
 
-  int err_num = pyos::Chdir(new Str("/"));
-  ASSERT(err_num == 0);
+TEST pyos_read_test() {
+  char* tmp_name = "_tmp/pyos_Read";
+  int fd = ::open(tmp_name, O_CREAT | O_RDWR, 0644);
+  if (fd < 0) {
+    printf("1. ERROR %s", strerror(errno));
+  }
+  ASSERT(fd > 0);
+  write(fd, "SH", 2);
+  close(fd);
 
-  err_num = pyos::Chdir(new Str("/nonexistent__"));
-  ASSERT(err_num != 0);
+  // open needs an absolute path for some reason?  _tmp/pyos doesn't work
+  fd = ::open(tmp_name, O_CREAT | O_RDWR, 0644);
+  if (fd < 0) {
+    printf("2. ERROR %s", strerror(errno));
+  }
 
-  Dict<Str*, Str*>* env = pyos::Environ();
-  Str* p = env->get(new Str("PATH"));
-  ASSERT(p != nullptr);
-  log("PATH = %s", p->data_);
+  List<Str*>* chunks = new List<Str*>();
+  Tuple2<int, int> tup = pyos::Read(fd, 4096, chunks);
+  ASSERT_EQ_FMT(2, tup.at0(), "%d");  // error code
+  ASSERT_EQ_FMT(0, tup.at1(), "%d");
+  ASSERT_EQ_FMT(1, len(chunks), "%d");
 
+  tup = pyos::Read(fd, 4096, chunks);
+  ASSERT_EQ_FMT(0, tup.at0(), "%d");  // error code
+  ASSERT_EQ_FMT(0, tup.at1(), "%d");
+  ASSERT_EQ_FMT(1, len(chunks), "%d");
+
+  close(fd);
 
   PASS();
 }
@@ -438,8 +474,13 @@ int main(int argc, char** argv) {
   RUN_TEST(exceptions);
   RUN_TEST(flag_spec_test);
   RUN_TEST(bool_stat_test);
-  RUN_TEST(pyos_test);
+  RUN_TEST(pyos_readbyte_test);
+  RUN_TEST(pyos_read_test);
   RUN_TEST(os_path_test);
+
+  // Must come last because it does chdir()
+  RUN_TEST(pyos_test);
+
   GREATEST_MAIN_END(); /* display results */
   return 0;
 }
