@@ -43,7 +43,10 @@ bool str_equals(Str* left, Str* right);
 namespace mylib {
 template <typename V>
 void dict_remove(Dict<Str*, V>* haystack, Str* needle);
-};
+
+template <typename V>
+void dict_remove(Dict<int, V>* haystack, int needle);
+};  // namespace mylib
 
 extern Str* kEmptyString;
 
@@ -115,7 +118,7 @@ class Str : public gc_heap::Obj {
   }
 
   // Get a string with one character
-  Str* index(int i) {
+  Str* index_(int i) {
     if (i < 0) {
       i = len_ + i;
     }
@@ -215,7 +218,28 @@ class Str : public gc_heap::Obj {
 
   // Used for CommandSub in osh/cmd_exec.py
   Str* rstrip(Str* chars) {
-    assert(0);
+    assert(chars->len_ == 1);
+    char c = chars->data_[0];
+
+    int last = len_ - 1;
+    int i = last;
+    bool done = false;
+    while (i > 0 && !done) {
+      if (data_[i] == c) {
+        i--;
+      } else {
+        done = true;
+        break;
+      }
+    }
+    if (i == last) {  // nothing stripped
+      return this;
+    }
+    int new_len = i + 1;
+    char* buf = static_cast<char*>(malloc(new_len + 1));
+    memcpy(buf, data_, new_len);
+    buf[new_len] = '\0';
+    return new Str(buf, new_len);
   }
 
   Str* rstrip() {
@@ -298,6 +322,10 @@ class Str : public gc_heap::Obj {
     return -1;
   }
 
+  int find(Str* needle, int pos) {
+    assert(0);
+  }
+
   int rfind(Str* needle) {
     assert(needle->len_ == 1);  // Oil's usage
     char c = needle->data_[0];
@@ -378,7 +406,8 @@ class List : public gc_heap::Obj {
     v_[index] = value;
   }
 
-  T index(int i) const {
+  // L[i]
+  T index_(int i) const {
     if (i < 0) {
       // User code doesn't result in mylist[-1], but Oil's own code does
       int j = v_.size() + i;
@@ -387,6 +416,18 @@ class List : public gc_heap::Obj {
     return v_.at(i);  // checked version
   }
 
+  // L.index(i) -- Python method
+  int index(T value) const {
+    int len = v_.size();
+    for (int i = 0; i < len; i++) {
+      // TODO: this doesn't work for strings!
+      if (v_[i] == value) {
+        return i;
+      }
+    }
+    throw new ValueError();
+  }
+
   // L[begin:]
   List* slice(int begin) {
     if (begin == 0) {
@@ -668,10 +709,10 @@ class Dict : public gc_heap::Obj {
   }
 
   // d[key] in Python: raises KeyError if not found
-  V index(K key) {
+  V index_(K key) {
     int pos = find(key);
     if (pos == -1) {
-      assert(0);
+      throw new KeyError();
     } else {
       return items_[pos].second;
     }
@@ -948,7 +989,7 @@ inline bool str_contains(Str* haystack, Str* needle) {
 inline bool list_contains(List<Str*>* haystack, Str* needle) {
   int n = haystack->v_.size();
   for (int i = 0; i < n; ++i) {
-    if (str_equals(haystack->index(i), needle)) {
+    if (str_equals(haystack->index_(i), needle)) {
       return true;
     }
   }
@@ -966,7 +1007,7 @@ template <typename T>
 List<T>* list(List<T>* other) {
   auto result = new List<T>();
   for (int i = 0; i < len(other); ++i) {
-    result->set(i, other->index(i));
+    result->set(i, other->index_(i));
   }
   return result;
 }
@@ -977,7 +1018,7 @@ template <typename T>
 inline bool list_contains(List<T>* haystack, T needle) {
   int n = haystack->v_.size();
   for (int i = 0; i < n; ++i) {
-    if (haystack->index(i) == needle) {
+    if (haystack->index_(i) == needle) {
       return true;
     }
   }
@@ -1031,7 +1072,6 @@ inline void mysort(std::vector<Str*>* v) {
 
 namespace mylib {  // MyPy artifact
 
-// TODO: how to do the int version of this?  Do you need an extra bit?
 template <typename V>
 inline void dict_remove(Dict<Str*, V>* haystack, Str* needle) {
   int pos = find_by_key(haystack->items_, needle);
@@ -1041,6 +1081,12 @@ inline void dict_remove(Dict<Str*, V>* haystack, Str* needle) {
   haystack->items_[pos].first = nullptr;
 }
 
+// TODO: how to do the int version of this?  Do you need an extra bit?
+template <typename V>
+inline void dict_remove(Dict<int, V>* haystack, int needle) {
+  assert(0);
+}
+
 // A class for interfacing Str* slices with C functions that expect a NUL
 // terminated string.  It's meant to be used on the stack, like
 //
